@@ -14,21 +14,7 @@ struct Optional {
 #[test]
 fn test() {
     #[cfg(not(feature = "serde-compat"))]
-    assert_eq!(
-        Optional::inline(0),
-        "\
-{
-    a?: number,
-    b: string | null,
-}"
-    );
+    assert_eq!(Optional::inline(), "{ a?: number, b: string | null, }");
     #[cfg(feature = "serde-compat")]
-    assert_eq!(
-        Optional::inline(0),
-        "\
-{
-    a?: number,
-    b?: string,
-}"
-    )
+    assert_eq!(Optional::inline(), "{ a?: number, b?: string, }")
 }
