@@ -1,18 +1,18 @@
 #![allow(dead_code)]
-
+use serde::Serialize;
 use ts_rs::TS;
 
-#[derive(TS)]
+#[derive(TS, Serialize)]
 struct Bar {
     field: i32,
 }
 
-#[derive(TS)]
+#[derive(TS, Serialize)]
 struct Foo {
     bar: Bar,
 }
 
-#[derive(TS)]
+#[derive(TS, Serialize)]
 enum SimpleEnum {
     A(String),
     B(i32),
@@ -27,6 +27,6 @@ fn test_stateful_enum() {
     assert_eq!(Foo::decl(), r#"interface Foo { bar: Bar, }"#);
     assert_eq!(
         SimpleEnum::decl(),
-        r#"type SimpleEnum = string | number | "C" | [string, number] | Foo | { a: number, b: string, };"#
+        r#"type SimpleEnum = { A: string } | { B: number } | "C" | { D: [string, number] } | { E: Foo } | { F: { a: number, b: string, } };"#
     );
 }
